Receiver

Struct Receiver 

pub struct Receiver<R: Deref<Target = State<Q, F, E>>, Q, F, E> { /* private fields */ }
Allows receiving data from the SPSC channel via its BulkProducer implementation.

Implementations

Source

impl<R: Deref<Target = State<Q, F, E>>, Q: Queue, F, E> Receiver<R, Q, F, E>

pub fn len(&self) -> usize

Returns the number of items that are currently buffered.

pub fn is_empty(&self) -> bool

Returns whether there are currently no items buffered.

pub fn is_receiver_dropped(&self) -> bool

Returns whether the correponding Sender has been dropped already.