Sender

Struct Sender 

pub struct Sender<R: Deref<Target = State<Q, F, E>>, Q, F, E> { /* private fields */ }
Allows sending data to the SPSC channel via its BulkConsumer implementation.

Implementations

Source

impl<R: Deref<Target = State<Q, F, E>>, Q: Queue, F, E> Sender<R, Q, F, E>

pub fn len(&self) -> usize

Returns the number of items that are currently buffered.

pub fn is_empty(&self) -> bool

Returns whether there are currently no items buffered.

pub fn cause_error(&mut self, err: E)

Sets an error to be emitted on the corresponding Receiver. The error is only emitted there when trying to produce values via produce or expose_items (or any method calling one of these), but never when slurping or calling consider_produced.

Must not call any of the Consumer, BufferedConsumer, or BulkProducer methods on this Receiver after calling this function, nor close_sync. May call this function at most once per Receiver. Must not call this function after calling close or close_sync.

pub fn close_sync(&mut self, fin: F)

Same as calling Consumer::close, but sync. Must not use this multiple times, after calling close, or after calling cause_error.

pub fn is_receiver_dropped(&self) -> bool

Returns whether the correponding Receiver has been dropped already.